
|Azure|_ |Azure-cov|_ |Azure-test|_ |binder|_

.. |Azure| image:: https://dev.azure.com/giotto-learn/giotto-learn/_apis/build/status/giotto-learn.giotto-learn?branchName=master
.. _Azure: https://dev.azure.com/giotto-learn/giotto-learn/

.. |Azure-cov| image:: https://coveralls.io/repos/neovim/neovim/badge.svg?branch=master
.. _Azure-cov: https://dev.azure.com/giotto-learn/giotto-learn/_build/results?buildId=364&view=codecoverage-tab

.. |Azure-test| image:: https://travis-ci.org/scikit-learn/scikit-learn.svg?branch=master
.. _Azure-test: https://dev.azure.com/giotto-learn/giotto-learn/_build/results?buildId=364&view=ms.vss-test-web.build-test-results-tab

.. |binder| image:: https://mybinder.org/badge_logo.svg
.. _binder: https://mybinder.org/v2/gh/giotto-learn/giotto-learn/master?filepath=examples

giotto-learn
============

C++ dependencies:
-----------------

-  C++14 compatible compiler
-  CMake >= 3.9
-  Boost >= 1.56

To install:
-----------

.. code-block:: bash

   git clone https://github.com/giotto-learn/giotto-learn.git
   cd giotto-learn
   pip install .


To use:
-------

.. code-block:: python

   import giotto as gt


Contacts:
---------

maintainers@giotto.ai
